import {
  select,
  csv, 
  scaleLinear,  
  max,
  extent,  
  scalePoint,
  axisLeft,
  axisBottom,  
  scaleTime,
  area,
  curveBasis,
  line,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'World Population by Year';
  const xAxisLabel = 'Time';
  const yAxisLabel = 'Population';
  const xValue = d => d.year;  
  const yValue = d => d.population;
  const circle_radius = 10;

  const margin = { top: 40, right: 100, bottom: 80, left: 80};
  const innerWidth = width - margin.left -margin.right;
  const innerheight = height - margin.top -margin.bottom;
  //console.log(height, margin.top, margin.bottom, innerheight);
  const xScale=scaleTime()
  	.domain(extent(data,xValue))
    //.domain([1950,2020])
  	.range([0,innerWidth]);
  console.log(innerWidth)
    
  const yScale = scaleLinear()
    .domain([0,max(data,yValue)])
    .range([innerheight,0])
    .nice(); 
    
  const xAxis = axisBottom(xScale)
    .ticks(6)
    .tickSize(-innerheight)
    .tickPadding(10);
  
  const yAxisTickFormat = number =>
    format('.1s')(number)
    .replace('G','B');
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
    .tickFormat(yAxisTickFormat);

  const g = svg.append('g')
    .attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0, ${innerheight})`);
  
  const yAxisG = g.append('g').call(yAxis);
      
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class','axis-label')
      .attr('y',60).attr('x',innerWidth/2)
      .attr('fill','black')
      .text(xAxisLabel);
  
  yAxisG.append('text')
      .attr('class','axis-label')
      .attr('y',-50)
      .attr('x',-innerheight/2 +50)
      .attr('fill','black')
      .attr('transform', `rotate(-90)`) 
      .attr('text-anchor','middle')
      .text(yAxisLabel);
  
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)));
  
  const areaGenerator = area()
    .x(d => xScale(xValue(d)))
    .y0(innerheight)
    .y1(d => yScale(yValue(d)))
    .curve(curveBasis);
   
  g.append('path')
     .attr('class','line-path')
     .attr('stroke','black')
     .attr('fill','none')
     .attr('d',areaGenerator(data));
  
  g.append('text')
      .attr('class','title')
      .attr('y',-5).attr('x',100)
      .text(title);
  
};



csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv')
  .then(data => {
	data.forEach( d=>{
    d.year = new Date(d.year);
    d.population = +d.population;  
  });  
  //console.log(data)
  render(data);
});